@@ -5,7 +5,7 @@ from .input_api_client import InputApiClient
 import click
 
 
-client = InputApiClient(auth=None, client_organization_id=3)
+client = InputApiClient(auth=None)
 
 
 def _tabulate(body, headers, title=None):
